=== modified file 'bzrlib/bundle/apply_bundle.py'
--- bzrlib/bundle/apply_bundle.py	2011-09-14 14:57:54 +0000
+++ bzrlib/bundle/apply_bundle.py	2011-09-20 11:46:28 +0000
@@ -18,10 +18,11 @@
 """
 
 from bzrlib import ui
+from bzrlib.i18n import gettext
+from bzrlib.merge import Merger
 from bzrlib.progress import ProgressPhase
-from bzrlib.merge import Merger
+from bzrlib.trace import note
 from bzrlib.vf_repository import install_revision
-from bzrlib.trace import note
 
 
 def install_bundle(repository, bundle_reader):
@@ -33,7 +34,7 @@
     try:
         real_revisions = bundle_reader.real_revisions
         for i, revision in enumerate(reversed(real_revisions)):
-            pb.update("Install revisions",i, len(real_revisions))
+            pb.update(gettext("Install revisions"),i, len(real_revisions))
             if repository.has_revision(revision.revision_id):
                 continue
             cset_tree = bundle_reader.revision_tree(repository,

=== modified file 'bzrlib/bundle/commands.py'
--- bzrlib/bundle/commands.py	2011-04-07 10:36:24 +0000
+++ bzrlib/bundle/commands.py	2011-09-20 13:31:00 +0000
@@ -32,6 +32,7 @@
     urlutils,
     transport,
     )
+from bzrlib.i18n import gettext
 """)
 
 from bzrlib.commands import Command
@@ -56,11 +57,11 @@
             bundle_info = read_bundle(bundle_file)
         else:
             if verbose:
-                raise errors.BzrCommandError('--verbose requires a merge'
-                    ' directive')
+                raise errors.BzrCommandError(gettext(
+                            '--verbose requires a merge directive'))
         reader_method = getattr(bundle_info, 'get_bundle_reader', None)
         if reader_method is None:
-            raise errors.BzrCommandError('Bundle format not supported')
+            raise errors.BzrCommandError(gettext('Bundle format not supported'))
 
         by_kind = {}
         file_ids = set()
@@ -70,13 +71,13 @@
                 (bytes, parents, repo_kind, revision_id, file_id))
             if file_id is not None:
                 file_ids.add(file_id)
-        self.outf.write('Records\n')
+        self.outf.write(gettext('Records\n'))
         for kind, records in sorted(by_kind.iteritems()):
             multiparent = sum(1 for b, m, k, r, f in records if
                               len(m.get('parents', [])) > 1)
-            self.outf.write('%s: %d (%d multiparent)\n' % \
-                (kind, len(records), multiparent))
-        self.outf.write('unique files: %d\n' % len(file_ids))
+            self.outf.write(gettext('{0}: {1} ({2} multiparent)\n').format(
+                kind, len(records), multiparent))
+        self.outf.write(gettext('unique files: %d\n') % len(file_ids))
         self.outf.write('\n')
         nicks = set()
         committers = set()
@@ -85,10 +86,10 @@
                 nicks.add(revision.properties['branch-nick'])
             committers.add(revision.committer)
 
-        self.outf.write('Revisions\n')
-        self.outf.write(('nicks: %s\n'
+        self.outf.write(gettext('Revisions\n'))
+        self.outf.write((gettext('nicks: %s\n')
             % ', '.join(sorted(nicks))).encode(term_encoding, 'replace'))
-        self.outf.write(('committers: \n%s\n' %
+        self.outf.write((gettext('committers: \n%s\n') %
         '\n'.join(sorted(committers)).encode(term_encoding, 'replace')))
         if verbose:
             self.outf.write('\n')
@@ -96,6 +97,6 @@
             line = bundle_file.readline()
             line = bundle_file.readline()
             content = bundle_file.read().decode('bz2')
-            self.outf.write("Decoded contents\n")
+            self.outf.write(gettext("Decoded contents\n"))
             self.outf.write(content)
             self.outf.write('\n')

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2011-09-19 15:59:40 +0000
+++ bzrlib/bzrdir.py	2011-09-20 10:47:29 +0000
@@ -2034,8 +2034,8 @@
                                     possible_transports=[self._bzrdir.root_transport])
             if not self._require_stacking:
                 # We have picked up automatic stacking somewhere.
-                note('Using default stacking branch %s at %s', self._stack_on,
-                    self._stack_on_pwd)
+                note(gettext('Using default stacking branch {0} at {1}').format(
+                    self._stack_on, self._stack_on_pwd))
         repository = self._bzrdir.create_repository(shared=shared)
         self._add_fallback(repository,
                            possible_transports=[self._bzrdir.transport])

=== modified file 'bzrlib/hooks.py'
--- bzrlib/hooks.py	2011-06-14 10:07:16 +0000
+++ bzrlib/hooks.py	2011-09-20 11:01:37 +0000
@@ -30,6 +30,7 @@
     errors,
     pyutils,
     )
+from bzrlib.i18n import gettext
 """)
 
 
@@ -310,10 +311,10 @@
             introduced_string = _format_version_tuple(self.introduced)
         else:
             introduced_string = 'unknown'
-        strings.append('Introduced in: %s' % introduced_string)
+        strings.append(gettext('Introduced in: %s') % introduced_string)
         if self.deprecated:
             deprecated_string = _format_version_tuple(self.deprecated)
-            strings.append('Deprecated in: %s' % deprecated_string)
+            strings.append(gettext('Deprecated in: %s') % deprecated_string)
         strings.append('')
         strings.extend(textwrap.wrap(self.__doc__,
             break_long_words=False))

=== modified file 'bzrlib/lockdir.py'
--- bzrlib/lockdir.py	2011-09-15 14:21:33 +0000
+++ bzrlib/lockdir.py	2011-09-20 13:31:00 +0000
@@ -137,6 +137,7 @@
         )
 from bzrlib.trace import mutter, note
 from bzrlib.osutils import format_delta, rand_chars, get_host_name
+from bzrlib.i18n import gettext
 
 from bzrlib.lazy_import import lazy_import
 lazy_import(globals(), """
@@ -316,7 +317,7 @@
             self.transport.delete(tmpname + self.__INFO_NAME)
             self.transport.rmdir(tmpname)
         except PathError, e:
-            note("error removing pending lock: %s", e)
+            note(gettext("error removing pending lock: %s"), e)
 
     def _create_pending_dir(self):
         tmpname = '%s/%s.tmp' % (self.path, rand_chars(10))
@@ -611,19 +612,20 @@
             new_info = self.peek()
             if new_info is not None and new_info != last_info:
                 if last_info is None:
-                    start = 'Unable to obtain'
+                    start = gettext('Unable to obtain')
                 else:
-                    start = 'Lock owner changed for'
+                    start = gettext('Lock owner changed for')
                 last_info = new_info
-                msg = u'%s lock %s %s.' % (start, lock_url, new_info)
+                msg = gettext('{0} lock {1} {2}.').format(start, lock_url,
+                                                                    new_info)
                 if deadline_str is None:
                     deadline_str = time.strftime('%H:%M:%S',
                                                     time.localtime(deadline))
                 if timeout > 0:
-                    msg += ('\nWill continue to try until %s, unless '
-                        'you press Ctrl-C.'
-                        % deadline_str)
-                msg += '\nSee "bzr help break-lock" for more.'
+                    msg += '\n' + gettext(
+                             'Will continue to try until %s, unless '
+                             'you press Ctrl-C.') % deadline_str
+                msg += '\n' + gettext('See "bzr help break-lock" for more.')
                 self._report_function(msg)
             if (max_attempts is not None) and (attempt_count >= max_attempts):
                 self._trace("exceeded %d attempts")
@@ -732,9 +734,9 @@
     def __unicode__(self):
         """Return a user-oriented description of this object."""
         d = self.to_readable_dict()
-        return (
+        return ( gettext(
             u'held by %(user)s on %(hostname)s (process #%(pid)s), '
-            u'acquired %(time_ago)s' % d)
+            u'acquired %(time_ago)s') % d)
 
     def to_readable_dict(self):
         """Turn the holder info into a dict of human-readable attributes.

=== modified file 'bzrlib/plugin.py'
--- bzrlib/plugin.py	2011-08-12 07:32:22 +0000
+++ bzrlib/plugin.py	2011-09-20 11:01:37 +0000
@@ -48,6 +48,7 @@
     errors,
     trace,
     )
+from bzrlib.i18n import gettext
 from bzrlib import plugins as _mod_plugins
 """)
 
@@ -137,8 +138,8 @@
         try:
             name, path = spec.split('@')
         except ValueError:
-            raise errors.BzrCommandError(
-                '"%s" is not a valid <plugin_name>@<plugin_path> description '
+            raise errors.BzrCommandError(gettext(
+                '"%s" is not a valid <plugin_name>@<plugin_path> description ')
                 % spec)
         specs.append((name, path))
     return specs

=== modified file 'bzrlib/plugins/launchpad/__init__.py'
--- bzrlib/plugins/launchpad/__init__.py	2011-08-21 09:24:01 +0000
+++ bzrlib/plugins/launchpad/__init__.py	2011-09-20 10:19:58 +0000
@@ -46,6 +46,7 @@
     ui,
     trace,
     )
+from bzrlib.i18n import gettext
 """)
 
 from bzrlib import (
@@ -144,14 +145,16 @@
             try:
                 b = _mod_branch.Branch.open_containing('.')[0]
             except NotBranchError:
-                raise BzrCommandError('register-branch requires a public '
-                    'branch url - see bzr help register-branch.')
+                raise BzrCommandError(gettext(
+                            'register-branch requires a public '
+                            'branch url - see bzr help register-branch.'))
             public_url = b.get_public_branch()
             if public_url is None:
                 raise NoPublicBranch(b)
         if product is not None:
             project = product
-            trace.note('--product is deprecated; please use --project.')
+            trace.note(gettext(
+                '--product is deprecated; please use --project.'))
 
 
         rego = BranchRegistrationRequest(branch_url=public_url,
@@ -223,7 +226,7 @@
         if location is None:
             location = u'.'
         web_url = self._get_web_url(LaunchpadService(), location)
-        trace.note('Opening %s in web browser' % web_url)
+        trace.note(gettext('Opening %s in web browser') % web_url)
         if not dry_run:
             import webbrowser   # this import should not be lazy
                                 # otherwise bzr.exe lacks this module
@@ -267,22 +270,23 @@
                 if check_account:
                     account.check_lp_login(username)
                     if verbose:
-                        self.outf.write(
-                            "Launchpad user ID exists and has SSH keys.\n")
+                        self.outf.write(gettext(
+                            "Launchpad user ID exists and has SSH keys.\n"))
                 self.outf.write(username + '\n')
             else:
-                self.outf.write('No Launchpad user ID configured.\n')
+                self.outf.write(gettext('No Launchpad user ID configured.\n'))
                 return 1
         else:
             name = name.lower()
             if check_account:
                 account.check_lp_login(name)
                 if verbose:
-                    self.outf.write(
-                        "Launchpad user ID exists and has SSH keys.\n")
+                    self.outf.write(gettext(
+                        "Launchpad user ID exists and has SSH keys.\n"))
             account.set_lp_login(name)
             if verbose:
-                self.outf.write("Launchpad user ID set to '%s'.\n" % (name,))
+                self.outf.write(gettext("Launchpad user ID set to '%s'.\n") %
+                                                                        (name,))
 
 register_command(cmd_launchpad_login)
 
@@ -400,8 +404,8 @@
             revno = self._find_merged_revno(revision, b, pb)
             merged = self._find_proposals(revno, b, pb)
             if len(merged) == 0:
-                raise BzrCommandError('No review found.')
-            trace.note('%d proposals(s) found.' % len(merged))
+                raise BzrCommandError(gettext('No review found.'))
+            trace.note(gettext('%d proposals(s) found.') % len(merged))
             for mp in merged:
                 webbrowser.open(lp_api.canonical_url(mp))
         finally:
@@ -411,27 +415,27 @@
     def _find_merged_revno(self, revision, b, pb):
         if revision is None:
             return b.revno()
-        pb.update('Finding revision-id')
+        pb.update(gettext('Finding revision-id'))
         revision_id = revision[0].as_revision_id(b)
         # a revno spec is necessarily on the mainline.
         if self._is_revno_spec(revision[0]):
             merging_revision = revision_id
         else:
             graph = b.repository.get_graph()
-            pb.update('Finding merge')
+            pb.update(gettext('Finding merge'))
             merging_revision = graph.find_lefthand_merger(
                 revision_id, b.last_revision())
             if merging_revision is None:
                 raise InvalidRevisionSpec(revision[0].user_spec, b)
-        pb.update('Finding revno')
+        pb.update(gettext('Finding revno'))
         return b.revision_id_to_revno(merging_revision)
 
     def _find_proposals(self, revno, b, pb):
         launchpad = lp_api.login(lp_registration.LaunchpadService())
-        pb.update('Finding Launchpad branch')
+        pb.update(gettext('Finding Launchpad branch'))
         lpb = lp_api.LaunchpadBranch.from_bzr(launchpad, b,
                                               create_missing=False)
-        pb.update('Finding proposals')
+        pb.update(gettext('Finding proposals'))
         return list(lpb.lp.getMergeProposals(status=['Merged'],
                                              merged_revnos=[revno]))
 

=== modified file 'bzrlib/plugins/launchpad/account.py'
--- bzrlib/plugins/launchpad/account.py	2011-07-23 16:33:38 +0000
+++ bzrlib/plugins/launchpad/account.py	2011-09-20 10:47:22 +0000
@@ -26,7 +26,7 @@
     transport,
     )
 from bzrlib.config import AuthenticationConfig, GlobalConfig
-
+from bzrlib.i18n import gettext
 
 LAUNCHPAD_BASE = 'https://launchpad.net/'
 
@@ -61,7 +61,7 @@
         auth_username = _get_auth_user(auth)
         # Auto-upgrading
         if auth_username is None:
-            trace.note('Setting ssh/sftp usernames for launchpad.net.')
+            trace.note(gettext('Setting ssh/sftp usernames for launchpad.net.'))
             _set_auth_user(username, auth)
         elif auth_username != username:
             raise MismatchedUsernames()

=== modified file 'bzrlib/plugins/launchpad/lp_api.py'
--- bzrlib/plugins/launchpad/lp_api.py	2011-02-11 05:27:33 +0000
+++ bzrlib/plugins/launchpad/lp_api.py	2011-09-20 10:19:58 +0000
@@ -33,6 +33,7 @@
     trace,
     transport,
     )
+from bzrlib.i18n import gettext
 from bzrlib.plugins.launchpad.lp_registration import (
     InvalidLaunchpadInstance,
     )
@@ -235,12 +236,13 @@
         """Create a Bazaar branch on Launchpad for the supplied branch."""
         url = cls.tweak_url(bzr_branch.get_push_location(), launchpad)
         if not cls.plausible_launchpad_url(url):
-            raise errors.BzrError('%s is not registered on Launchpad' %
+            raise errors.BzrError(gettext('%s is not registered on Launchpad') %
                                   bzr_branch.base)
         bzr_branch.create_clone_on_transport(transport.get_transport(url))
         lp_branch = launchpad.branches.getByUrl(url=url)
         if lp_branch is None:
-            raise errors.BzrError('%s is not registered on Launchpad' % url)
+            raise errors.BzrError(gettext('%s is not registered on Launchpad') %
+                                                                            url)
         return lp_branch
 
     def get_target(self):
@@ -249,18 +251,21 @@
         if lp_branch.project is not None:
             dev_focus = lp_branch.project.development_focus
             if dev_focus is None:
-                raise errors.BzrError('%s has no development focus.' %
+                raise errors.BzrError(gettext('%s has no development focus.') %
                                   lp_branch.bzr_identity)
             target = dev_focus.branch
             if target is None:
-                raise errors.BzrError('development focus %s has no branch.' % dev_focus)
+                raise errors.BzrError(gettext(
+                        'development focus %s has no branch.') % dev_focus)
         elif lp_branch.sourcepackage is not None:
             target = lp_branch.sourcepackage.getBranch(pocket="Release")
             if target is None:
-                raise errors.BzrError('source package %s has no branch.' %
+                raise errors.BzrError(gettext(
+                                      'source package %s has no branch.') %
                                       lp_branch.sourcepackage)
         else:
-            raise errors.BzrError('%s has no associated product or source package.' %
+            raise errors.BzrError(gettext(
+                        '%s has no associated product or source package.') %
                                   lp_branch.bzr_identity)
         return LaunchpadBranch(target, target.bzr_identity)
 
@@ -272,14 +277,14 @@
         try:
             if self.lp.last_scanned_id is not None:
                 if self.bzr.last_revision() == self.lp.last_scanned_id:
-                    trace.note('%s is already up-to-date.' %
+                    trace.note(gettext('%s is already up-to-date.') %
                                self.lp.bzr_identity)
                     return
                 graph = self.bzr.repository.get_graph()
                 if not graph.is_ancestor(self.lp.last_scanned_id,
                                          self.bzr.last_revision()):
                     raise errors.DivergedBranches(self.bzr, self.push_bzr)
-                trace.note('Pushing to %s' % self.lp.bzr_identity)
+                trace.note(gettext('Pushing to %s') % self.lp.bzr_identity)
             self.bzr.push(self.push_bzr)
         finally:
             self.bzr.unlock()

=== modified file 'bzrlib/plugins/launchpad/lp_directory.py'
--- bzrlib/plugins/launchpad/lp_directory.py	2011-03-24 11:38:25 +0000
+++ bzrlib/plugins/launchpad/lp_directory.py	2011-09-20 14:11:27 +0000
@@ -26,6 +26,7 @@
     trace,
     transport,
     )
+from bzrlib.i18n import gettext
 
 from bzrlib.plugins.launchpad.lp_registration import (
     LaunchpadService, ResolveLaunchpadPathRequest)
@@ -164,8 +165,9 @@
             if 'launchpad' in debug.debug_flags:
                 local_res = result
                 result = self._resolve_via_xmlrpc(path, url, _request_factory)
-                trace.note('resolution for %s\n  local: %s\n remote: %s'
-                           % (url, local_res['urls'], result['urls']))
+                trace.note(gettext(
+                    'resolution for {0}\n  local: {1}\n remote: {2}').format(
+                           url, local_res['urls'], result['urls']))
         else:
             result = self._resolve_via_xmlrpc(path, url, _request_factory)
 

=== modified file 'bzrlib/plugins/launchpad/lp_propose.py'
--- bzrlib/plugins/launchpad/lp_propose.py	2011-04-07 10:36:24 +0000
+++ bzrlib/plugins/launchpad/lp_propose.py	2011-09-20 10:19:58 +0000
@@ -142,8 +142,8 @@
             if mp.queue_status in ('Merged', 'Rejected'):
                 continue
             if mp.target_branch.self_link == self.target_branch.lp.self_link:
-                raise errors.BzrCommandError(
-                    'There is already a branch merge proposal: %s' %
+                raise errors.BzrCommandError(gettext(
+                    'There is already a branch merge proposal: %s') %
                     lp_api.canonical_url(mp))
 
     def _get_prerequisite_branch(self):

=== modified file 'bzrlib/plugins/weave_fmt/bzrdir.py'
--- bzrlib/plugins/weave_fmt/bzrdir.py	2011-09-08 17:55:39 +0000
+++ bzrlib/plugins/weave_fmt/bzrdir.py	2011-09-20 13:31:00 +0000
@@ -44,6 +44,7 @@
     weave,
     xml5,
     )
+from bzrlib.i18n import gettext
 from bzrlib.store.versioned import VersionedFileStore
 from bzrlib.transactions import WriteTransaction
 from bzrlib.transport import (
@@ -222,10 +223,10 @@
         """See Converter.convert()."""
         self.bzrdir = to_convert
         if pb is not None:
-            warnings.warn("pb parameter to convert() is deprecated")
+            warnings.warn(gettext("pb parameter to convert() is deprecated"))
         self.pb = ui.ui_factory.nested_progress_bar()
         try:
-            ui.ui_factory.note('starting upgrade from format 4 to 5')
+            ui.ui_factory.note(gettext('starting upgrade from format 4 to 5'))
             if isinstance(self.bzrdir.transport, local.LocalTransport):
                 self.bzrdir.get_workingtree_transport(None).delete('stat-cache')
             self._convert_to_weaves()
@@ -234,7 +235,8 @@
             self.pb.finished()
 
     def _convert_to_weaves(self):
-        ui.ui_factory.note('note: upgrade may be faster if all store files are ungzipped first')
+        ui.ui_factory.note(gettext(
+          'note: upgrade may be faster if all store files are ungzipped first'))
         try:
             # TODO permissions
             stat = self.bzrdir.transport.stat('weaves')
@@ -263,15 +265,17 @@
         self.pb.clear()
         to_import = self._make_order()
         for i, rev_id in enumerate(to_import):
-            self.pb.update('converting revision', i, len(to_import))
+            self.pb.update(gettext('converting revision'), i, len(to_import))
             self._convert_one_rev(rev_id)
         self.pb.clear()
         self._write_all_weaves()
         self._write_all_revs()
-        ui.ui_factory.note('upgraded to weaves:')
-        ui.ui_factory.note('  %6d revisions and inventories' % len(self.revisions))
-        ui.ui_factory.note('  %6d revisions not present' % len(self.absent_revisions))
-        ui.ui_factory.note('  %6d texts' % self.text_count)
+        ui.ui_factory.note(gettext('upgraded to weaves:'))
+        ui.ui_factory.note('  ' + gettext('%6d revisions and inventories') %
+                                                        len(self.revisions))
+        ui.ui_factory.note('  ' + gettext('%6d revisions not present') %
+                                                    len(self.absent_revisions))
+        ui.ui_factory.note('  ' + gettext('%6d texts') % self.text_count)
         self._cleanup_spare_files_after_format4()
         self.branch._transport.put_bytes(
             'branch-format',
@@ -307,12 +311,13 @@
         try:
             i = 0
             for file_id, file_weave in self.text_weaves.items():
-                self.pb.update('writing weave', i, len(self.text_weaves))
+                self.pb.update(gettext('writing weave'), i,
+                                                        len(self.text_weaves))
                 weaves._put_weave(file_id, file_weave, transaction)
                 i += 1
-            self.pb.update('inventory', 0, 1)
+            self.pb.update(gettext('inventory'), 0, 1)
             controlweaves._put_weave('inventory', self.inv_weave, transaction)
-            self.pb.update('inventory', 1, 1)
+            self.pb.update(gettext('inventory'), 1, 1)
         finally:
             self.pb.clear()
 
@@ -329,7 +334,8 @@
             lambda:True, lambda:True)
         try:
             for i, rev_id in enumerate(self.converted_revs):
-                self.pb.update('write revision', i, len(self.converted_revs))
+                self.pb.update(gettext('write revision'), i,
+                                                len(self.converted_revs))
                 text = serializer_v5.write_revision_to_string(
                     self.revisions[rev_id])
                 key = (rev_id,)
@@ -342,13 +348,13 @@
 
         Any parents not either loaded or abandoned get queued to be
         loaded."""
-        self.pb.update('loading revision',
+        self.pb.update(gettext('loading revision'),
                        len(self.revisions),
                        len(self.known_revisions))
         if not self.branch.repository.has_revision(rev_id):
             self.pb.clear()
-            ui.ui_factory.note('revision {%s} not present in branch; '
-                         'will be converted as a ghost' %
+            ui.ui_factory.note(gettext('revision {%s} not present in branch; '
+                         'will be converted as a ghost') %
                          rev_id)
             self.absent_revisions.add(rev_id)
         else:
@@ -487,7 +493,7 @@
         self.bzrdir = to_convert
         pb = ui.ui_factory.nested_progress_bar()
         try:
-            ui.ui_factory.note('starting upgrade from format 5 to 6')
+            ui.ui_factory.note(gettext('starting upgrade from format 5 to 6'))
             self._convert_to_prefixed()
             return BzrDir.open(self.bzrdir.user_url)
         finally:
@@ -497,7 +503,7 @@
         from bzrlib.store import TransportStore
         self.bzrdir.transport.delete('branch-format')
         for store_name in ["weaves", "revision-store"]:
-            ui.ui_factory.note("adding prefixes to %s" % store_name)
+            ui.ui_factory.note(gettext("adding prefixes to %s") % store_name)
             store_transport = self.bzrdir.transport.clone(store_name)
             store = TransportStore(store_transport, prefixed=True)
             for urlfilename in store_transport.list_dir('.'):
@@ -537,7 +543,7 @@
         self.dir_mode = self.bzrdir._get_dir_mode()
         self.file_mode = self.bzrdir._get_file_mode()
 
-        ui.ui_factory.note('starting upgrade from format 6 to metadir')
+        ui.ui_factory.note(gettext('starting upgrade from format 6 to metadir'))
         self.bzrdir.transport.put_bytes(
                 'branch-format',
                 "Converting to format 6",
@@ -545,12 +551,12 @@
         # its faster to move specific files around than to open and use the apis...
         # first off, nuke ancestry.weave, it was never used.
         try:
-            self.step('Removing ancestry.weave')
+            self.step(gettext('Removing ancestry.weave'))
             self.bzrdir.transport.delete('ancestry.weave')
         except errors.NoSuchFile:
             pass
         # find out whats there
-        self.step('Finding branch files')
+        self.step(gettext('Finding branch files'))
         last_revision = self.bzrdir.open_branch().last_revision()
         bzrcontents = self.bzrdir.transport.list_dir('.')
         for name in bzrcontents:
@@ -560,7 +566,7 @@
         repository_names = [('inventory.weave', True),
                             ('revision-store', True),
                             ('weaves', True)]
-        self.step('Upgrading repository  ')
+        self.step(gettext('Upgrading repository') + '  ')
         self.bzrdir.transport.mkdir('repository', mode=self.dir_mode)
         self.make_lock('repository')
         # we hard code the formats here because we are converting into
@@ -570,7 +576,7 @@
         for entry in repository_names:
             self.move_entry('repository', entry)
 
-        self.step('Upgrading branch      ')
+        self.step(gettext('Upgrading branch') + '      ')
         self.bzrdir.transport.mkdir('branch', mode=self.dir_mode)
         self.make_lock('branch')
         self.put_format('branch', BzrBranchFormat5())
@@ -593,14 +599,14 @@
         else:
             has_checkout = True
         if not has_checkout:
-            ui.ui_factory.note('No working tree.')
+            ui.ui_factory.note(gettext('No working tree.'))
             # If some checkout files are there, we may as well get rid of them.
             for name, mandatory in checkout_files:
                 if name in bzrcontents:
                     self.bzrdir.transport.delete(name)
         else:
             from bzrlib.workingtree_3 import WorkingTreeFormat3
-            self.step('Upgrading working tree')
+            self.step(gettext('Upgrading working tree'))
             self.bzrdir.transport.mkdir('checkout', mode=self.dir_mode)
             self.make_lock('checkout')
             self.put_format(
@@ -621,7 +627,7 @@
 
     def make_lock(self, name):
         """Make a lock for the new control dir name."""
-        self.step('Make %s lock' % name)
+        self.step(gettext('Make %s lock') % name)
         ld = lockdir.LockDir(self.bzrdir.transport,
                              '%s/lock' % name,
                              file_modebits=self.file_mode,
@@ -632,7 +638,7 @@
         """Move then entry name into new_dir."""
         name = entry[0]
         mandatory = entry[1]
-        self.step('Moving %s' % name)
+        self.step(gettext('Moving %s') % name)
         try:
             self.bzrdir.transport.move(name, '%s/%s' % (new_dir, name))
         except errors.NoSuchFile:

=== modified file 'bzrlib/transport/ftp/_gssapi.py'
--- bzrlib/transport/ftp/_gssapi.py	2010-05-31 21:31:18 +0000
+++ bzrlib/transport/ftp/_gssapi.py	2011-09-20 10:49:47 +0000
@@ -24,6 +24,7 @@
 from bzrlib import (
     errors,
     )
+from bzrlib.i18n import gettext
 from bzrlib.trace import mutter
 from bzrlib.transport.ftp import FtpTransport
 
@@ -79,8 +80,8 @@
                         if not ((resp.startswith('235 ') and rc == 1) or
                                 (resp.startswith('335 ') and rc == 0)):
                             raise ftplib.error_reply, resp
-            trace.note("Authenticated as %s" % kerberos.authGSSClientUserName(
-                    self.vc))
+            trace.note(gettext("Authenticated as %s") %
+                            kerberos.authGSSClientUserName(self.vc))
 
             # Monkey patch ftplib
             self.putcmd = self.mic_putcmd

